@@ -31,9 +31,12 @@ import (
 )
 
 const (
+	ENV_CACHE        = "STAYRTR_CACHE"
 	ENV_SSH_PASSWORD = "STAYRTR_SSH_PASSWORD"
 	ENV_SSH_KEY      = "STAYRTR_SSH_AUTHORIZEDKEYS"
 
+	DEFAULT_CACHE = "https://console.rpki-client.org/rpki.json"
+
 	METHOD_NONE = iota
 	METHOD_PASSWORD
 	METHOD_KEY
@@ -80,7 +83,7 @@ var (
 
 	TimeCheck = flag.Bool("checktime", true, "Check if JSON file isn't stale (disable by passing -checktime=false)")
 
-	CacheBin = flag.String("cache", "https://console.rpki-client.org/rpki.json", "URL of the Validated RPKI data in JSON format")
+	CacheBin = flag.String("cache", DEFAULT_CACHE, fmt.Sprintf("URL of the Validated RPKI data in JSON format (if blank, will use envvar %v", ENV_CACHE))
 
 	Etag            = flag.Bool("etag", true, "Control usage of Etag header (disable with -etag=false)")
 	LastModified    = flag.Bool("last.modified", true, "Control usage of Last-Modified header (disable with -last.modified=false)")
@@ -169,9 +172,12 @@ func initMetrics() {
 	prometheus.MustRegister(CurrentSerial)
 }
 
-func serveHTTP() {
-	http.Handle(*MetricsPath, promhttp.Handler())
-	log.Fatal(http.ListenAndServe(*MetricsAddr, nil))
+func serveHTTP(mux *http.ServeMux) {
+	srv := &http.Server{
+		Addr:    *MetricsAddr,
+		Handler: mux,
+	}
+	log.Fatal(srv.ListenAndServe())
 }
 
 // newSHA256 will return the sha256 sum of the byte slice
@@ -536,6 +542,16 @@ func (s *state) updateDelay(delay *time.Ticker, interval int) {
 	}
 }
 
+func (s *state) errRPKIJsonFileTooOldHandler() {
+	// If the exiting build time is over 24 hours, It's time to drop everything out.
+	// to avoid routing on stale data
+	buildTime := s.exported.Metadata.GetBuildTime()
+	if !buildTime.IsZero() && time.Since(buildTime) > time.Hour*24 {
+		log.Errorf("Data is stale, clearing it all.")
+		s.server.AddData([]rtr.SendableData{}) // empty the store of sendable stuff, triggering a emptying of the RTR server
+	}
+}
+
 func (s *state) routineUpdate(file string, interval int, slurmFile string) {
 	log.Debugf("Starting refresh routine (file: %v, interval: %vs, slurm: %v)", file, interval, slurmFile)
 	signals := make(chan os.Signal, 1)
@@ -609,20 +625,18 @@ func (s *state) routineUpdate(file string, interval int, slurmFile string) {
 		if cacheUpdated || slurmNotPresentOrUpdated {
 			err := s.updateFromNewState()
 			if err != nil {
-				if err == errRPKIJsonFileTooOld {
-					// If the exiting build time is over 24 hours, It's time to drop everything out.
-					// to avoid routing on stale data
-					buildTime := s.exported.Metadata.GetBuildTime()
-					if !buildTime.IsZero() && time.Since(buildTime) > time.Hour*24 {
-						s.server.AddData([]rtr.SendableData{}) // empty the store of sendable stuff, triggering a emptying of the RTR server
-					}
-				}
 				log.Errorf("Error updating from new state: %v", err)
+				if err == errRPKIJsonFileTooOld {
+					s.errRPKIJsonFileTooOldHandler()
+				}
 			}
 		} else {
 			err := s.reloadFromCurrentState()
 			if err != nil {
-				log.Errorf("Error updating state: %v", err)
+				log.Errorf("Error updating from current state: %v", err)
+				if err == errRPKIJsonFileTooOld {
+					s.errRPKIJsonFileTooOldHandler()
+				}
 			}
 		}
 	}
@@ -795,14 +809,23 @@ func run() error {
 	s.fetchConfig.EnableEtags = *Etag
 	s.fetchConfig.EnableLastModified = *LastModified
 
+	if *CacheBin == DEFAULT_CACHE && os.Getenv(ENV_CACHE) != "" {
+		*CacheBin = os.Getenv(ENV_CACHE)
+	}
+
 	if enableHTTP {
+		mux := http.NewServeMux()
+		mux.Handle(*MetricsPath, promhttp.Handler())
+		mux.HandleFunc("GET /clients", server.GetClientRemoteAddrs)
+
 		if *ExportPath != "" {
-			http.HandleFunc(*ExportPath, s.exporter)
+			mux.HandleFunc(*ExportPath, s.exporter)
 		}
 		if *EnableUpdateEndpoint {
-			http.HandleFunc("/api/update", s.updateNow)
+			mux.HandleFunc("/api/update", s.updateNow)
 		}
-		go serveHTTP()
+
+		go serveHTTP(mux)
 	}
 
 	if *Bind == "" && *BindTLS == "" && *BindSSH == "" {
